@@ -1207,10 +1207,9 @@ void txt_cpu_wakeup(void)
         return;
     }
 
-    printk(TBOOT_INFO"Mutex lock cpu %u\n", cpuid);
     mtx_enter(&ap_lock);
 
-    printk(TBOOT_INFO"cpu %u waking up from TXT sleep\n", cpuid);
+    printk(TBOOT_INFO"waking cpu %u\n", cpuid);
 
     /* restore LAPIC base address for AP */
     madt_apicbase = (uint64_t)get_madt_apic_base();
@@ -1221,7 +1220,6 @@ void txt_cpu_wakeup(void)
     }
     msr_apicbase = rdmsr(MSR_APICBASE);
     if ( madt_apicbase != (msr_apicbase & ~0xFFFULL) ) {
-        printk(TBOOT_INFO"cpu %u restore apic base to %llx\n", cpuid, madt_apicbase);
         wrmsr(MSR_APICBASE, (msr_apicbase & 0xFFFULL) | madt_apicbase);
     }
 
@@ -1238,7 +1236,6 @@ void txt_cpu_wakeup(void)
         apply_policy(TB_ERR_POST_LAUNCH_VERIFICATION);
 
     /* enable SMIs and NMI */
-    printk(TBOOT_DETA"enabling SMIs and NMI on cpu %u\n", cpuid);
     __getsec_smctrl();
     __enable_nmi();
 
