@@ -673,31 +673,19 @@ bool verify_stm(unsigned int cpuid)
     apicbase = rdmsr(MSR_APICBASE);
     if ( apicbase & APICBASE_BSP ) {
         ilp_smm_mon_ctl = smm_mon_ctl;
-        printk(TBOOT_DETA"MSR for SMM monitor control on BSP is 0x%Lx.\n",
-               ilp_smm_mon_ctl);
 
         /* verify ILP's MSEG == TXT.MSEG.BASE */
-        printk(TBOOT_INFO"verifying ILP is opt-out "
-               "or has the same MSEG header with TXT.MSEG.BASE\n\t");
         if ( !verify_mseg(ilp_smm_mon_ctl) ) {
-            printk(TBOOT_ERR" : failed.\n");
+            printk(TBOOT_ERR"verifying ILP is opt-out or has the same MSEG header with TXT.MSEG.BASE failed.\n");
             return false;
         }
-        printk(TBOOT_INFO" : succeeded.\n");
     }
     else {
-        printk(TBOOT_DETA"MSR for SMM monitor control on cpu %u is 0x%Lx\n",
-               cpuid, smm_mon_ctl);
-
         /* verify ILP's SMM MSR == RLP's SMM MSR */
-        printk(TBOOT_INFO"verifying ILP's MSR_IA32_SMM_MONITOR_CTL with cpu %u\n\t",
-               cpuid);
         if ( smm_mon_ctl != ilp_smm_mon_ctl ) {
-            printk(TBOOT_ERR" : failed.\n");
+            printk(TBOOT_ERR" : verifying ILP's MSR_IA32_SMM_MONITOR_CTL with cpu %u failed.\n", cpuid);
             return false;
         }
-        printk(TBOOT_INFO" : succeeded.\n");
-
         /* since the RLP's MSR is the same. No need to verify MSEG header */
     }
 
